$.jqplot.CategoryAxisRenderer

A plugin for jqPlot to render a category style axis, with equal pixel spacing between y data values of a series.

To use this renderer, include the plugin in your source

>     <script type="text/javascript" language="javascript" src="plugins/jqplot.categoryAxisRenderer.js"></script>

and supply the appropriate options to your plot

>     {axes:{xaxis:{renderer:$.jqplot.CategoryAxisRenderer}}}

Summary

$.jqplot.CategoryAxisRenderer | A plugin for jqPlot to render a category style axis, with equal pixel spacing between y data values of a series.
Properties |
sortMergedLabels | True to sort tick labels when labels are created by merging x axis values from multiple series.
tickRenderer | A class of a rendering engine for creating the ticks labels displayed on the plot, See $.jqplot.AxisTickRenderer.

### Properties

### sortMergedLabels

> this.sortMergedLabels = false

True to sort tick labels when labels are created by merging x axis values from multiple series. That is, say you have two series like:

>     line1 = [[2006, 4],            [2008, 9], [2009, 16]];
>     line2 = [[2006, 3], [2007, 7], [2008, 6]];

If no label array is specified, tick labels will be collected from the x values of the series. With sortMergedLabels set to true, tick labels will be:

>     [2006, 2007, 2008, 2009]

With sortMergedLabels set to false, tick labels will be:

>     [2006, 2008, 2009, 2007]

Note, this property is specified on the renderOptions for the axes when creating a plot:

>     axes:{xaxis:{renderer:$.jqplot.CategoryAxisRenderer, rendererOptions:{sortMergedLabels:true}}}

### tickRenderer

A class of a rendering engine for creating the ticks labels displayed on the plot, See $.jqplot.AxisTickRenderer. this.tickRenderer = $.jqplot.AxisTickRenderer; this.labelRenderer = $.jqplot.AxisLabelRenderer;

> this.sortMergedLabels = false

True to sort tick labels when labels are created by merging x axis values from multiple series.
A “tick” object showing the value of a tick/gridline on the plot.
Close